==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/ConnectorGroup.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.entity.collection.request.ApplicationCollectionRequest;
import odata.msgraph.client.beta.entity.collection.request.ConnectorCollectionRequest;
import odata.msgraph.client.beta.enums.ConnectorGroupRegion;
import odata.msgraph.client.beta.enums.ConnectorGroupType;


/**
 * <p>
 * <b>Org.OData.Capabilities.V1.ExpandRestrictions</b>
 * <p>
 * Expandable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.NavigationRestrictions</b>
 * <p>
 * Referenceable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.SelectRestrictions</b>
 * <p>
 * Selectable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.CountRestrictions</b>
 * <p>
 * Countable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.FilterRestrictions</b>
 * <p>
 * Filterable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.TopSupported</b>
 * <p>
 * true
 * <p>
 * <b>Org.OData.Capabilities.V1.SkipSupported</b>
 * <p>
 * true
 */@JsonPropertyOrder({
    "@odata.type", 
    "name", 
    "connectorGroupType", 
    "isDefault", 
    "region"})
@JsonInclude(Include.NON_NULL)
public class ConnectorGroup extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.connectorGroup";
    }

    @JsonProperty("name")
    protected String name;

    @JsonProperty("connectorGroupType")
    protected ConnectorGroupType connectorGroupType;

    @JsonProperty("isDefault")
    protected Boolean isDefault;

    @JsonProperty("region")
    protected ConnectorGroupRegion region;

    protected ConnectorGroup() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderConnectorGroup() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String name;
        private ConnectorGroupType connectorGroupType;
        private Boolean isDefault;
        private ConnectorGroupRegion region;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder connectorGroupType(ConnectorGroupType connectorGroupType) {
            this.connectorGroupType = connectorGroupType;
            this.changedFields = changedFields.add("connectorGroupType");
            return this;
        }

        public Builder isDefault(Boolean isDefault) {
            this.isDefault = isDefault;
            this.changedFields = changedFields.add("isDefault");
            return this;
        }

        public Builder region(ConnectorGroupRegion region) {
            this.region = region;
            this.changedFields = changedFields.add("region");
            return this;
        }

        public ConnectorGroup build() {
            ConnectorGroup _x = new ConnectorGroup();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.connectorGroup";
            _x.id = id;
            _x.name = name;
            _x.connectorGroupType = connectorGroupType;
            _x.isDefault = isDefault;
            _x.region = region;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="name")
    @JsonIgnore
    public Optional<String> getName() {
        return Optional.ofNullable(name);
    }

    public ConnectorGroup withName(String name) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("name");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.name = name;
        return _x;
    }

    @Property(name="connectorGroupType")
    @JsonIgnore
    public Optional<ConnectorGroupType> getConnectorGroupType() {
        return Optional.ofNullable(connectorGroupType);
    }

    public ConnectorGroup withConnectorGroupType(ConnectorGroupType connectorGroupType) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("connectorGroupType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.connectorGroupType = connectorGroupType;
        return _x;
    }

    @Property(name="isDefault")
    @JsonIgnore
    public Optional<Boolean> getIsDefault() {
        return Optional.ofNullable(isDefault);
    }

    public ConnectorGroup withIsDefault(Boolean isDefault) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("isDefault");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.isDefault = isDefault;
        return _x;
    }

    @Property(name="region")
    @JsonIgnore
    public Optional<ConnectorGroupRegion> getRegion() {
        return Optional.ofNullable(region);
    }

    public ConnectorGroup withRegion(ConnectorGroupRegion region) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("region");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.region = region;
        return _x;
    }

    @NavigationProperty(name="members")
    @JsonIgnore
    public ConnectorCollectionRequest getMembers() {
        return new ConnectorCollectionRequest(
                        contextPath.addSegment("members"));
    }

    @NavigationProperty(name="applications")
    @JsonIgnore
    public ApplicationCollectionRequest getApplications() {
        return new ApplicationCollectionRequest(
                        contextPath.addSegment("applications"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ConnectorGroup patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ConnectorGroup _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ConnectorGroup put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ConnectorGroup _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ConnectorGroup _copy() {
        ConnectorGroup _x = new ConnectorGroup();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.name = name;
        _x.connectorGroupType = connectorGroupType;
        _x.isDefault = isDefault;
        _x.region = region;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ConnectorGroup[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("connectorGroupType=");
        b.append(this.connectorGroupType);
        b.append(", ");
        b.append("isDefault=");
        b.append(this.isDefault);
        b.append(", ");
        b.append("region=");
        b.append(this.region);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/ConnectorGroup.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.entity.collection.request.ApplicationCollectionRequest;
import odata.msgraph.client.beta.entity.collection.request.ConnectorCollectionRequest;
import odata.msgraph.client.beta.enums.ConnectorGroupRegion;
import odata.msgraph.client.beta.enums.ConnectorGroupType;


/**
 * <p>
 * <b>Org.OData.Capabilities.V1.CountRestrictions</b>
 * <p>
 * Countable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.ExpandRestrictions</b>
 * <p>
 * Expandable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.FilterRestrictions</b>
 * <p>
 * Filterable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.NavigationRestrictions</b>
 * <p>
 * Referenceable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.SelectRestrictions</b>
 * <p>
 * Selectable = true
 * <p>
 * <b>Org.OData.Capabilities.V1.SkipSupported</b>
 * <p>
 * true
 * <p>
 * <b>Org.OData.Capabilities.V1.TopSupported</b>
 * <p>
 * true
 */@JsonPropertyOrder({
    "@odata.type", 
    "connectorGroupType", 
    "isDefault", 
    "name", 
    "region"})
@JsonInclude(Include.NON_NULL)
public class ConnectorGroup extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.connectorGroup";
    }

    @JsonProperty("connectorGroupType")
    protected ConnectorGroupType connectorGroupType;

    @JsonProperty("isDefault")
    protected Boolean isDefault;

    @JsonProperty("name")
    protected String name;

    @JsonProperty("region")
    protected ConnectorGroupRegion region;

    protected ConnectorGroup() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderConnectorGroup() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private ConnectorGroupType connectorGroupType;
        private Boolean isDefault;
        private String name;
        private ConnectorGroupRegion region;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder connectorGroupType(ConnectorGroupType connectorGroupType) {
            this.connectorGroupType = connectorGroupType;
            this.changedFields = changedFields.add("connectorGroupType");
            return this;
        }

        public Builder isDefault(Boolean isDefault) {
            this.isDefault = isDefault;
            this.changedFields = changedFields.add("isDefault");
            return this;
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder region(ConnectorGroupRegion region) {
            this.region = region;
            this.changedFields = changedFields.add("region");
            return this;
        }

        public ConnectorGroup build() {
            ConnectorGroup _x = new ConnectorGroup();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.connectorGroup";
            _x.id = id;
            _x.connectorGroupType = connectorGroupType;
            _x.isDefault = isDefault;
            _x.name = name;
            _x.region = region;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="connectorGroupType")
    @JsonIgnore
    public Optional<ConnectorGroupType> getConnectorGroupType() {
        return Optional.ofNullable(connectorGroupType);
    }

    public ConnectorGroup withConnectorGroupType(ConnectorGroupType connectorGroupType) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("connectorGroupType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.connectorGroupType = connectorGroupType;
        return _x;
    }

    @Property(name="isDefault")
    @JsonIgnore
    public Optional<Boolean> getIsDefault() {
        return Optional.ofNullable(isDefault);
    }

    public ConnectorGroup withIsDefault(Boolean isDefault) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("isDefault");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.isDefault = isDefault;
        return _x;
    }

    @Property(name="name")
    @JsonIgnore
    public Optional<String> getName() {
        return Optional.ofNullable(name);
    }

    public ConnectorGroup withName(String name) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("name");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.name = name;
        return _x;
    }

    @Property(name="region")
    @JsonIgnore
    public Optional<ConnectorGroupRegion> getRegion() {
        return Optional.ofNullable(region);
    }

    public ConnectorGroup withRegion(ConnectorGroupRegion region) {
        ConnectorGroup _x = _copy();
        _x.changedFields = changedFields.add("region");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.connectorGroup");
        _x.region = region;
        return _x;
    }

    public ConnectorGroup withUnmappedField(String name, Object value) {
        ConnectorGroup _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @NavigationProperty(name="applications")
    @JsonIgnore
    public ApplicationCollectionRequest getApplications() {
        return new ApplicationCollectionRequest(
                        contextPath.addSegment("applications"), RequestHelper.getValue(unmappedFields, "applications"));
    }

    @NavigationProperty(name="members")
    @JsonIgnore
    public ConnectorCollectionRequest getMembers() {
        return new ConnectorCollectionRequest(
                        contextPath.addSegment("members"), RequestHelper.getValue(unmappedFields, "members"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ConnectorGroup patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        ConnectorGroup _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public ConnectorGroup put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        ConnectorGroup _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private ConnectorGroup _copy() {
        ConnectorGroup _x = new ConnectorGroup();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.connectorGroupType = connectorGroupType;
        _x.isDefault = isDefault;
        _x.name = name;
        _x.region = region;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ConnectorGroup[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("connectorGroupType=");
        b.append(this.connectorGroupType);
        b.append(", ");
        b.append("isDefault=");
        b.append(this.isDefault);
        b.append(", ");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("region=");
        b.append(this.region);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
